# Wind Farm Classes

The wind farm classes define how the wind farm's graph model are created, and power the
timing out of the failures and maintenance events within the simulation for the cables,
substations, and turbines.

## Wind Farm

```{eval-rst}
.. automodule:: wombat.windfarm.windfarm
   :members:
   :undoc-members:
```

## System: Wind turbine or substation

```{eval-rst}
.. automodule:: wombat.windfarm.system.system
   :members:
   :undoc-members:
```

## Subassembly: The modeled components of a system

```{eval-rst}
.. automodule:: wombat.windfarm.system.subassembly
   :members:
   :undoc-members:
```

## Cable: Hybrid system and subassembly model

```{eval-rst}
.. automodule:: wombat.windfarm.system.cable
   :members:
   :undoc-members:
```
